==> org.robokind.api.speech-0.8.6-sources.jar: org/robokind/api/speech/messaging/RemoteSpeechServiceClient.java <==
/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.speech.messaging;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.robokind.api.common.utils.EventRepeater;
import org.jflux.api.core.Listener;
import org.robokind.api.common.utils.TimeUtils;
import org.robokind.api.messaging.MessageAsyncReceiver;
import org.robokind.api.messaging.MessageSender;
import org.robokind.api.messaging.services.DefaultServiceClient;
import org.robokind.api.messaging.services.ServiceCommand;
import org.robokind.api.messaging.services.ServiceCommandFactory;
import org.robokind.api.messaging.services.ServiceError;
import org.robokind.api.speech.SpeechEvent;
import org.robokind.api.speech.SpeechEventList;
import org.robokind.api.speech.SpeechRequest;
import org.robokind.api.speech.SpeechRequestFactory;
import org.robokind.api.speech.SpeechService;
import org.robokind.api.speech.utils.SpeechEventNotifier;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class RemoteSpeechServiceClient<Conf> extends 
        DefaultServiceClient<Conf> implements SpeechService{
    private final static Logger theLogger = 
            Logger.getLogger(RemoteSpeechServiceClient.class.getName());
    private String mySpeechServiceId;
    private MessageSender<SpeechRequest> myRequestSender;
    private MessageAsyncReceiver<SpeechEventList> myEventReceiver;
    private SpeechEventNotifier mySpeechEventNotifier;
    private SpeechRequestFactory myRequestFactory;
    /**
     * Add request listeners to an EventRepeater rather than the RequestSender
     * in order to retain listeners when the sender changes.
     */
    private EventRepeater<SpeechRequest> myRequestRepeater;
    /**
     * Connects to a remote SpeechService through Messaging components
     */
    public RemoteSpeechServiceClient(
            Class<Conf> configClass,
            String speechServiceId,
            String remoteId,
            MessageSender<ServiceCommand> commandSender,
            MessageSender<Conf> configSender,
            MessageAsyncReceiver<ServiceError> errorReceiver,
            ServiceCommandFactory commandFactory,
            MessageSender<SpeechRequest> requestSender,
            MessageAsyncReceiver<SpeechEventList> eventReceiver,
            SpeechRequestFactory requestFactory){
        super(speechServiceId, remoteId, 
                commandSender, configSender, errorReceiver, commandFactory);
        if(speechServiceId == null){
            throw new NullPointerException();
        }
        mySpeechServiceId = speechServiceId;
        mySpeechEventNotifier = new SpeechEventNotifier();
        myRequestSender = requestSender;
        myRequestRepeater = new EventRepeater();
        if(myRequestSender != null){
            myRequestSender.addListener(myRequestRepeater);
        }
        myRequestFactory = requestFactory;
        myEventReceiver = eventReceiver;
        if(myEventReceiver != null){
            myEventReceiver.addListener(mySpeechEventNotifier);
        }
    }
    
    @Override
    public String getSpeechServiceId(){
        return mySpeechServiceId;
    }
    
    @Override
    public void start() throws Exception{
        start(TimeUtils.now());
    }

    @Override
    public void speak(String text) {
        if(text == null){
            throw new NullPointerException();
        }if(myRequestSender == null || myRequestFactory == null){
            theLogger.warning("Unable to send speech request, "
                    + "Request Sender or Factory is null.");
            return;
        }
        theLogger.log(Level.INFO, "Speaking: {0}", text);
        SpeechRequest req = 
                myRequestFactory.create(getClientId(), getHostId(), text);
        myRequestSender.notifyListeners(req);
    }
    
    @Override
    public void cancelSpeech(){
        send("cancelSpeech");
    }

    @Override
    public void stop() {
        super.stop(TimeUtils.now());
        myEventReceiver.stop();
        myRequestSender.stop();
    }
    
    public void setSpeechRequestSender(MessageSender<SpeechRequest> sender){
        if(myRequestSender != null){
            myRequestSender.removeListener(myRequestRepeater);
        }
        myRequestSender = sender;
        if(myRequestSender != null){
            myRequestSender.addListener(myRequestRepeater);
        }
    }
    
    public void setSpeechEventsReceiver(
            MessageAsyncReceiver<SpeechEventList> receiver){
        if(myEventReceiver != null){
            myEventReceiver.removeListener(mySpeechEventNotifier);
        }
        myEventReceiver = receiver;
        if(myEventReceiver != null){
            myEventReceiver.addListener(mySpeechEventNotifier);
        }
    }
    
    public void setSpeechRequestFactory(SpeechRequestFactory factory){
        myRequestFactory = factory;
    }

    @Override
    public void addRequestListener(Listener<SpeechRequest> listener) {
        myRequestRepeater.addListener(listener);
    }

    @Override
    public void removeRequestListener(Listener<SpeechRequest> listener) {
        myRequestRepeater.removeListener(listener);
    }

    @Override
    public void addSpeechEventListener(Listener<SpeechEvent> listener) {
        mySpeechEventNotifier.addSpeechEventListener(listener);
    }

    @Override
    public void removeSpeechEventListener(Listener<SpeechEvent> listener) {
        mySpeechEventNotifier.removeSpeechEventListener(listener);
    }
    
}

==> org.robokind.api.speech-0.8.9.2-sources.jar: org/robokind/api/speech/messaging/RemoteSpeechServiceClient.java <==
/*
 * Copyright 2012 Hanson Robokind LLC.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robokind.api.speech.messaging;

import java.util.logging.Level;
import java.util.logging.Logger;
import org.robokind.api.common.utils.EventRepeater;
import org.jflux.api.core.Listener;
import org.robokind.api.common.utils.TimeUtils;
import org.robokind.api.messaging.MessageAsyncReceiver;
import org.robokind.api.messaging.MessageSender;
import org.robokind.api.messaging.services.DefaultServiceClient;
import org.robokind.api.messaging.services.ServiceCommand;
import org.robokind.api.messaging.services.ServiceCommandFactory;
import org.robokind.api.messaging.services.ServiceError;
import org.robokind.api.speech.SpeechEvent;
import org.robokind.api.speech.SpeechEventList;
import org.robokind.api.speech.SpeechJob;
import org.robokind.api.speech.SpeechRequest;
import org.robokind.api.speech.SpeechRequestFactory;
import org.robokind.api.speech.SpeechService;
import org.robokind.api.speech.utils.SpeechEventNotifier;
import org.robokind.api.speech.utils.SpeechJobManager;

/**
 *
 * @author Matthew Stevenson <www.robokind.org>
 */
public class RemoteSpeechServiceClient<Conf> extends 
        DefaultServiceClient<Conf> implements SpeechService{
    private final static Logger theLogger = 
            Logger.getLogger(RemoteSpeechServiceClient.class.getName());
    private String mySpeechServiceId;
    private MessageSender<SpeechRequest> myRequestSender;
    private MessageAsyncReceiver<SpeechEventList<SpeechEvent>> myEventReceiver;
    private SpeechEventNotifier mySpeechEventNotifier;
    private SpeechRequestFactory myRequestFactory;
    private SpeechJobManager myJobManager;
    /**
     * Add request listeners to an EventRepeater rather than the RequestSender
     * in order to retain listeners when the sender changes.
     */
    private EventRepeater<SpeechRequest> myRequestRepeater;
    /**
     * Connects to a remote SpeechService through Messaging components
     */
    public RemoteSpeechServiceClient(
            Class<Conf> configClass,
            String speechServiceId,
            String remoteId,
            MessageSender<ServiceCommand> commandSender,
            MessageSender<Conf> configSender,
            MessageAsyncReceiver<ServiceError> errorReceiver,
            ServiceCommandFactory commandFactory,
            MessageSender<SpeechRequest> requestSender,
            MessageAsyncReceiver<SpeechEventList<SpeechEvent>> eventReceiver,
            SpeechRequestFactory requestFactory){
        super(speechServiceId, remoteId, 
                commandSender, configSender, errorReceiver, commandFactory);
        if(speechServiceId == null){
            throw new NullPointerException();
        }
        mySpeechServiceId = speechServiceId;
        mySpeechEventNotifier = new SpeechEventNotifier();
        myRequestSender = requestSender;
        myRequestRepeater = new EventRepeater();
        if(myRequestSender != null){
            myRequestSender.addListener(myRequestRepeater);
        }
        myRequestFactory = requestFactory;
        myEventReceiver = eventReceiver;
        if(myEventReceiver != null){
            myEventReceiver.addListener(mySpeechEventNotifier);
        }
        myJobManager = new SpeechJobManager(this);
    }
    
    @Override
    public String getSpeechServiceId(){
        return mySpeechServiceId;
    }
    
    @Override
    public void start() throws Exception{
        start(TimeUtils.now());
    }

    @Override
    public SpeechJob speak(String text) {
        if(text == null){
            throw new NullPointerException();
        }if(myRequestSender == null || myRequestFactory == null){
            theLogger.warning("Unable to send speech request, "
                    + "Request Sender or Factory is null.");
            return null;
        }
        theLogger.log(Level.INFO, "Speaking: {0}", text);
        SpeechRequest req = 
                myRequestFactory.create(getClientId(), getHostId(), text);
        myRequestSender.notifyListeners(req);
        return myJobManager.createSpeechJob(text);
    }
    
    @Override
    public void cancelSpeech(){
        send("cancelSpeech");
    }

    @Override
    public void stop() {
        super.stop(TimeUtils.now());
        myEventReceiver.stop();
        myRequestSender.stop();
    }
    
    public void setSpeechRequestSender(MessageSender<SpeechRequest> sender){
        if(myRequestSender != null){
            myRequestSender.removeListener(myRequestRepeater);
        }
        myRequestSender = sender;
        if(myRequestSender != null){
            myRequestSender.addListener(myRequestRepeater);
        }
    }
    
    public void setSpeechEventsReceiver(
            MessageAsyncReceiver<SpeechEventList<SpeechEvent>> receiver){
        if(myEventReceiver != null){
            myEventReceiver.removeListener(mySpeechEventNotifier);
        }
        myEventReceiver = receiver;
        if(myEventReceiver != null){
            myEventReceiver.addListener(mySpeechEventNotifier);
        }
    }
    
    public void setSpeechRequestFactory(SpeechRequestFactory factory){
        myRequestFactory = factory;
    }

    @Override
    public void addRequestListener(Listener<SpeechRequest> listener) {
        myRequestRepeater.addListener(listener);
    }

    @Override
    public void removeRequestListener(Listener<SpeechRequest> listener) {
        myRequestRepeater.removeListener(listener);
    }

    @Override
    public void addSpeechEventListener(Listener<SpeechEventList<SpeechEvent>> listener) {
        mySpeechEventNotifier.addSpeechEventListener(listener);
    }

    @Override
    public void removeSpeechEventListener(Listener<SpeechEventList<SpeechEvent>> listener) {
        mySpeechEventNotifier.removeSpeechEventListener(listener);
    }
    
}
